task spladder_EC {
    String sample_id
    File bam
    File reference_gtf_file
    File spladder
	File samples


    String event_types
    String spladder_docker
    String spladder_cluster
    String disk_size

    
    command <<<
        set -o pipefail
        set -e

        mkdir -p ${sample_id}/spladder_out/spladder
        
        ln -s ${bam}/*.bam ./
        cat ${samples} | while read a; do ls ./ | grep bam$ | grep $a; done > alignment.txt
       
        ln -s ${bam}/*.bai ./
        cat ${samples} | while read a; do ls ./ | grep bai$ | grep $a; done > alignment_bai.txt

        cp -r ${spladder}/* ${sample_id}/spladder_out/spladder/
        ls ${sample_id}/spladder_out/spladder/ > spladder.txt


        nt=$(nproc)
		
        spladder build -o ${sample_id}/spladder_out \
          --annotation ${reference_gtf_file} \
          --bams alignment.txt \
          --parallel $nt \
          --confidence 2 \
          --readlen 150 \
          --event-types ${event_types}
          
          
        find . -depth > fileList.txt
    >>>

    runtime {
        docker: spladder_docker
        cluster: spladder_cluster
        systemDisk: "cloud_ssd 50"
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
        timeout: 129600
    }

    output {
        File fileList = "fileList.txt"
        File alignment = "alignment.txt"
        File alignment_bai = "alignment_bai.txt"
        File spladder_txt = "spladder.txt"
        Array[File] AS_gff = glob("${sample_id}/spladder_out/*.gff3")
        Array[File] AS_gz = glob("${sample_id}/spladder_out/*.gz")
        Array[File] spladder_out = glob("${sample_id}/spladder_out/*")
        Array[File] spladder_file = glob("${sample_id}/spladder_out/spladder/*")          
    }
}